@@ -1,12 +1,10 @@
-from pathlib import Path
-
-import click
-import yaml
 import os
 import os.path
 import sys
-from sdccli import drop
-from sdccli import restore
+from pathlib import Path
+
+import click
+
 from sdccli.usecases.backup import *
 
 
@@ -131,71 +129,65 @@ def restore_from_backup(cnf, backup_file, section, full, all_users):
         print("Error: {} is not a correct backup file".format(backup_file))
         sys.exit(1)
 
-    sdmonitor = cnf.sdmonitor
-    sdsecure = cnf.sdsecure
-
     use_cases_to_execute = []
 
     if not section or 'dashboards' in section:
         if full:
             if all_users:
-                use_cases_to_execute.append(
-                    RemoveAllAndRestoreAllDashboardsUseCase(sdmonitor, open(backup_file, mode='r')))
+                use_cases_to_execute.append(RemoveAllAndRestoreAllDashboardsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
             else:
-                use_cases_to_execute.append(
-                    RemoveOwnedAndRestoreOwnedDashboardsUseCase(sdmonitor, open(backup_file, mode='r')))
+                use_cases_to_execute.append(RemoveOwnedAndRestoreOwnedDashboardsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
         else:
             if all_users:
-                use_cases_to_execute.append(RestoreAllDashboardsUseCase(sdmonitor, open(backup_file, mode='r')))
+                use_cases_to_execute.append(RestoreAllDashboardsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
             else:
-                use_cases_to_execute.append(RestoreOwnedDashboardsUseCase(sdmonitor, open(backup_file, mode='r')))
+                use_cases_to_execute.append(RestoreOwnedDashboardsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
 
     if not section or 'notification_channels' in section:
         if full:
-            use_cases_to_execute.append(
-                RemoveAndRestoreNotificationChannelsUseCase(sdmonitor, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RemoveAndRestoreNotificationChannelsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
         else:
-            use_cases_to_execute.append(RestoreNotificationChannelsUseCase(sdmonitor, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RestoreNotificationChannelsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
 
     if not section or 'alerts' in section:
         if full:
-            use_cases_to_execute.append(RemoveAndRestoreAlertsUseCase(sdmonitor, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RemoveAndRestoreAlertsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
         else:
-            use_cases_to_execute.append(RestoreAlertsUseCase(sdmonitor, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RestoreAlertsUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
 
     if not section or 'users' in section:
-        use_cases_to_execute.append(RestoreUsersUseCase(sdmonitor, open(backup_file, mode='r')))
+        use_cases_to_execute.append(RestoreUsersUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
 
     if not section or 'teams_monitor' in section:
         if full:
-            use_cases_to_execute.append(RemoveAndRestoreTeamsMonitorUseCase(sdmonitor, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RemoveAndRestoreTeamsMonitorUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
         else:
-            use_cases_to_execute.append(RestoreTeamsMonitorUseCase(sdmonitor, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RestoreTeamsMonitorUseCase(cnf.sdmonitor, open(backup_file, mode='r')))
 
     if not section or 'teams_secure' in section:
         if full:
-            use_cases_to_execute.append(RemoveAndRestoreTeamsSecureUseCase(sdsecure, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RemoveAndRestoreTeamsSecureUseCase(cnf.sdsecure, open(backup_file, mode='r')))
         else:
-            use_cases_to_execute.append(RestoreTeamsSecureUseCase(sdsecure, open(backup_file, mode='r')))
+            use_cases_to_execute.append(RestoreTeamsSecureUseCase(cnf.sdsecure, open(backup_file, mode='r')))
 
     if full:
         if not section or 'policies' in section:
-            use_cases_to_execute.append(RemovePoliciesUseCase(sdsecure))
+            use_cases_to_execute.append(RemovePoliciesUseCase(cnf.sdsecure))
         if not section or 'falco_rules' in section:
-            use_cases_to_execute.append(RemoveFalcoRulesUseCase(sdsecure))
+            use_cases_to_execute.append(RemoveFalcoRulesUseCase(cnf.sdsecure))
         if not section or 'falco_macros' in section:
-            use_cases_to_execute.append(RemoveFalcoMacrosUseCase(sdsecure))
+            use_cases_to_execute.append(RemoveFalcoMacrosUseCase(cnf.sdsecure))
         if not section or 'falco_lists' in section:
-            use_cases_to_execute.append(RemoveFalcoListsUseCase(sdsecure))
+            use_cases_to_execute.append(RemoveFalcoListsUseCase(cnf.sdsecure))
 
     if not section or 'falco_lists' in section:
-        use_cases_to_execute.append(RestoreFalcoListsUseCase(sdsecure, open(backup_file, mode='r')))
+        use_cases_to_execute.append(RestoreFalcoListsUseCase(cnf.sdsecure, open(backup_file, mode='r')))
     if not section or 'falco_macros' in section:
-        use_cases_to_execute.append(RestoreFalcoMacrosUseCase(sdsecure, open(backup_file, mode='r')))
+        use_cases_to_execute.append(RestoreFalcoMacrosUseCase(cnf.sdsecure, open(backup_file, mode='r')))
     if not section or 'falco_rules' in section:
-        use_cases_to_execute.append(RestoreFalcoRulesUseCase(sdsecure, open(backup_file, mode='r')))
+        use_cases_to_execute.append(RestoreFalcoRulesUseCase(cnf.sdsecure, open(backup_file, mode='r')))
     if not section or 'policies' in section:
-        use_cases_to_execute.append(RestorePoliciesUseCase(sdsecure, open(backup_file, mode='r')))
+        use_cases_to_execute.append(RestorePoliciesUseCase(cnf.sdsecure, open(backup_file, mode='r')))
 
     errors = []
     for use_case in use_cases_to_execute:
