@@ -47,8 +47,10 @@ def add(cnf, name, templatefile, scope, public):
 
 @dashboard.command(name='add-json', short_help="Add dashboards from a json file")
 @click.argument('jsonfile', nargs=1, type=click.Path(exists=True))
+@click.option('--ignore-sharing-settings', is_flag=True, help="Ignores the sharing settings configured in the JSON, "
+                                                              "not sending them to the API")
 @click.pass_obj
-def add_json(cnf, jsonfile):
+def add_json(cnf, jsonfile, ignore_sharing_settings):
     """
     JSONFILE: A file with a json description of one or multiple dashboards
     """
@@ -60,12 +62,34 @@ def add_json(cnf, jsonfile):
         sys.exit(1)
 
     try:
-        res = use_case.add_json_dashboard(cnf.sdmonitor, dashboard_json)
+        res = use_case.add_json_dashboard(cnf.sdmonitor, dashboard_json, ignore_sharing_settings)
         cnf.formatter.format(res, "dashboard")
     except Exception as ex:
         print(f"Error: {str(ex)}")
         sys.exit(1)
 
+@dashboard.command(name='update-json', short_help="Update dashboards from a json file")
+@click.argument('jsonfile', nargs=1, type=click.Path(exists=True))
+@click.option('--ignore-sharing-settings', is_flag=True, help="Ignores the sharing settings configured in the JSON, "
+                                                              "not sending them to the API")
+@click.pass_obj
+def update_json(cnf, jsonfile, ignore_sharing_settings):
+    """
+    JSONFILE: A file with a json description of one or multiple dashboards
+    """
+    try:
+        with open(jsonfile) as f:
+            dashboard_json = json.load(f)
+    except Exception as error:
+        print("Error parsing rules file (%s): %s" % (jsonfile, str(error)))
+        sys.exit(1)
+
+    try:
+        res = use_case.update_json_dashboard(cnf.sdmonitor, dashboard_json, ignore_sharing_settings)
+        cnf.formatter.format(res, "dashboard")
+    except Exception as ex:
+        print(f"Error: {str(ex)}")
+        sys.exit(1)
 
 @dashboard.command(name='list', short_help="List all dashboards")
 @click.pass_obj
