@@ -399,7 +399,8 @@ def policies(file_data, secure: SdSecureClient):
             scope=policy['scope'] if 'scope' in policy else None,
             severity=policy['severity'],
             enabled=policy['enabled'],
-            notification_channels=policy['notificationChannelIds']
+            notification_channels=policy['notificationChannelIds'],
+            type=policy.get('type', 'falco')
         )
         if not ok:
             errors.append(result)
