@@ -149,13 +149,16 @@ def add_panel_to_dashboard(monitor, dashboard, panel):
     return res["dashboard"]
 
 
-def add_json_dashboard(monitor, dashboard):
+def add_json_dashboard(monitor, dashboard, remove_sharing_settings=False):
     result = ""
 
     def add_json(monitor, dboard):
         if "dashboard" in dboard:
             dboard = dboard["dashboard"]
 
+        if remove_sharing_settings:
+            dboard['sharingSettings'] = []
+            dboard['shared'] = False
         dboard['timeMode'] = {'mode': 1}
         dboard['time'] = {'last': 2 * 60 * 60 * 1000000, 'sampling': 2 * 60 * 60 * 1000000}
         ok, res = monitor.create_dashboard_with_configuration(dboard)
@@ -175,6 +178,43 @@ def add_json_dashboard(monitor, dashboard):
     return result
 
 
+def update_json_dashboard(monitor, dashboard, remove_sharing_settings=False):
+    result = ""
+
+    def update_json(monitor, dboard):
+        if "dashboard" in dboard:
+            dboard = dboard["dashboard"]
+        # If the dashboard exists, update it. If not, create it
+        try:
+            found = get_dashboard_by_id_or_name(monitor, dboard['id'])
+        except: 
+            return add_json_dashboard(monitor, dboard)
+        if remove_sharing_settings:
+            dboard['sharingSettings'] = []
+            dboard['shared'] = False
+        dboard['timeMode'] = {'mode': 1}
+        dboard['time'] = {'last': 2 * 60 * 60 * 1000000, 'sampling': 2 * 60 * 60 * 1000000}
+        ok, res = monitor.update_dashboard(dboard)
+        if ok:
+            return "Updated dashboard {}".format(dboard['name'])
+        if "status code 409" in res:            
+            raise Exception("Error updating for existing more recent version in dashboard {}: {}".format(dboard['name'], res))
+        else:
+            raise Exception("Error updating the dashboard {}: {}".format(dboard['name'], res))
+        
+
+
+    if isinstance(dashboard, list):
+        for db in dashboard:
+            result += update_json(monitor, db) + "\n"
+    elif isinstance(dashboard, dict):
+        result = update_json(monitor, dashboard)
+    else:
+        raise Exception("Unsupported JSON format")
+
+    return result
+
+
 def remove_panel_from_dashboard(monitor, dashboard, name):
     ok, res = monitor.remove_dashboard_panel(dashboard, name)
 
